@@ -9,23 +9,13 @@ class BounceException(Exception):
 
 logger = logging.getLogger(__name__)
 
-SESSION_APP = None
-
-
-def get_session_app():
-    global SESSION_APP
-    if SESSION_APP is None:
-        from ..models import LokApp
-        SESSION_APP, created = LokApp.objects.get_or_create(client_id="session", name="Session", grant_type=LokGrantType.SESSION.value)
-    
-    return SESSION_APP
 
 
 class Bounced:
 
-    def __init__(self, user, app, scopes, token=None, is_jwt=False) -> None:
+    def __init__(self, user, client, scopes, token=None, is_jwt=False) -> None:
         self._user = user
-        self._app = app
+        self._client = client
         self._scopes = scopes or []
         self.scopeset = set(self._scopes)
         self.is_jwt = is_jwt
@@ -35,9 +25,13 @@ class Bounced:
     def user(self):
         return self._user
 
+    @property
+    def client(self):
+        return self._client
+
     @property
     def app(self):
-        return self._app
+        return self._client.app
 
     @property
     def scopes(self):
@@ -56,23 +50,19 @@ class Bounced:
         if only_jwt and not self.is_jwt:
             raise BounceException("Only Apps authorized via JWT are allowed here")
        
-        if self._app.grant_type == LokGrantType.CLIENT_CREDENTIALS.value:
+        if self._client.grant_type == LokGrantType.CLIENT_CREDENTIALS.value:
             if not required_scopes.issubset(self.scopeset):
                 raise BounceException(f"App has not the required Scopes. Required {required_scopes}")
 
-        if self._app.grant_type == LokGrantType.IMPLICIT.value:
+        if self._client.grant_type == LokGrantType.IMPLICIT.value:
             if not anonymous and self.user.is_anonymous:
                 raise BounceException("Only signed in users are allowed here")
     
         # Scope tests
-        if self._app.grant_type == LokGrantType.PASSWORD.value:
+        if self._client.grant_type == LokGrantType.PASSWORD.value:
             return True
 
 
     @classmethod
     def from_auth(cls, auth: JwtToken):
         return cls(auth.user, auth.app, auth.scopes, token=auth.token, is_jwt=True)
-
-    @classmethod
-    def from_session_app_and_user(cls, sessionApp, user):
-        return cls(user, sessionApp, [])
\ No newline at end of file
