@@ -1,7 +1,7 @@
 import asyncio
 from asgiref.sync import sync_to_async
 from django.utils.decorators import sync_and_async_middleware
-from ...bouncer.bounced import Bounced, get_session_app
+from ...bouncer.bounced import Bounced
 
 
 
@@ -14,13 +14,10 @@ def BouncedMiddleware(get_response):
             # Do something here!
             if hasattr(request, "auth"):
                 bounced = Bounced.from_auth(request.auth)
-                request.bounced = Bounced.from_auth(request.auth)
+                setattr(request, "bounced", bounced)
                 setattr(request, "user", bounced.user)
-            elif hasattr(request, "session"):
-                app = await sync_to_async(get_session_app)()
-                request.bounced = Bounced.from_session_app_and_user(app, request.user)
-            else:
-                request.bounced = None
+                setattr(request, "app", bounced.app)
+                setattr(request, "client", bounced.client)
             response = await get_response(request)
             return response
 
@@ -29,13 +26,10 @@ def BouncedMiddleware(get_response):
             # Do something here!
             if hasattr(request, "auth"):
                 bounced = Bounced.from_auth(request.auth)
-                request.bounced = bounced
+                setattr(request, "bounced", bounced)
                 setattr(request, "user", bounced.user)
-            elif hasattr(request, "session"):
-                app = get_session_app()
-                request.bounced = Bounced.from_session_app_and_user(app, request.user)
-            else:
-                request.bounced = None
+                setattr(request, "app", bounced.app)
+                setattr(request, "client", bounced.client)
             response = get_response(request)
             return response
 
