@@ -4,7 +4,7 @@ import logging
 from django.conf import settings
 from django.core.exceptions import  PermissionDenied
 from django.contrib.auth import get_user_model
-from ...bouncer.bounced import Bounced, get_session_app
+from ...bouncer.bounced import Bounced
 from asgiref.sync import sync_to_async
 
 logger = logging.getLogger(__name__)
@@ -31,11 +31,7 @@ class BouncerChannelMiddleware:
             bounced =  Bounced.from_auth(scope["auth"])
             scope["bounced"]= bounced
             scope["user"] = bounced.user
-            scope["app"] = bounced.app
-        elif "session" in scope:
-            app = await sync_to_async(get_session_app)()
-            bounced = Bounced.from_session_app_and_user(app, scope["user"])
-            scope["bounced"] = bounced
+            scope["client"] = bounced.client
             scope["app"] = bounced.app
         else:
             scope["bounced"] = None
